@@ -145,6 +145,28 @@ CIFGetOutputScale(convert)
 		(float)(CIFCurStyle->cs_expander * convert));
 }
 
+/*
+ * ----------------------------------------------------------------------------
+ *
+ * CIFGetScale --
+ *
+ *  Same as the above routine, but provides the scalefactor to get CIF
+ *  units from centimicrons (which generally means just returning the
+ *  expander value to show if units have been declared in nanometers or
+ *  angstroms).
+ *
+ * ----------------------------------------------------------------------------
+ */
+
+float
+CIFGetScale(convert)
+   int convert;
+{
+    if (CIFCurStyle == NULL) return 1.0;
+
+    return (1.0 / (float)(CIFCurStyle->cs_expander * convert));
+}
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -237,7 +259,8 @@ CIFSetStyle(name)
 				 * print out the valid styles.
 				 */
 {
-    CIFKeep *style, *match;
+    CIFKeep *style, *match, *exactmatch;
+    bool ambiguous = FALSE;
     int length;
 
     if (name == NULL) return;
@@ -247,18 +270,25 @@ CIFSetStyle(name)
 
     for (style = CIFStyleList; style != NULL; style = style->cs_next)
     {
-	if (strncmp(name, style->cs_name, length) == 0)
+	if (!strcmp(name, style->cs_name)) {
+	    match = style;
+	    ambiguous = FALSE;
+	    break;
+	}
+	else if (!strncmp(name, style->cs_name, length))
 	{
-	    if (match != NULL)
-	    {
-		TxError("CIF output style \"%s\" is ambiguous.\n", name);
-		CIFPrintStyle(FALSE, TRUE, TRUE);
-		return;
-	    }
+	    if (match != NULL) ambiguous = TRUE;
 	    match = style;
 	}
     }
 
+    if (ambiguous)
+    {
+	TxError("CIF output style \"%s\" is ambiguous.\n", name);
+	CIFPrintStyle(FALSE, TRUE, TRUE);
+	return;
+    }
+
     if (match != NULL)
     {
 	CIFLoadStyle(match->cs_name);
