@@ -42,6 +42,11 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #include "cif/cif.h"
 #include "drc/drc.h"	/* For WRL's DRC-CIF extensions */
 
+/* C99 compat */
+#include "calma/calma.h"
+#include "dbwind/dbwind.h"
+#include "drc/drc.h"
+
 /* The following statics are used to keep track of things between
  * calls to CIFTechLine.
  */
@@ -183,6 +188,7 @@ cifTechStyleInit()
     {
 	CIFCurStyle->cs_labelLayer[i] = -1;
 	CIFCurStyle->cs_portLayer[i] = -1;
+	CIFCurStyle->cs_portText[i] = -1;
     }
     for (i = 0; i < MAXCIFLAYERS; i++)
 	CIFCurStyle->cs_layers[i] = NULL;
@@ -866,7 +872,7 @@ CIFTechLine(sectionName, argc, argv)
 
     if (strcmp(argv[0], "labels") == 0)
     {
-	bool portOnly = FALSE, noPort = FALSE;
+	bool portOnly = FALSE, noPort = FALSE, textOnly = FALSE;
 
 	if (cifCurLayer == NULL)
 	{
@@ -881,6 +887,8 @@ CIFTechLine(sectionName, argc, argv)
 		portOnly = TRUE;
 	    else if (!strncmp(argv[2], "noport", 6))
 		noPort = TRUE;
+	    else if (!strncmp(argv[2], "text", 6))
+		textOnly = TRUE;
 	    else
 	    {
 		TechError("Unknown option %s for labels statement.\n", argv[2]);
@@ -893,10 +901,28 @@ CIFTechLine(sectionName, argc, argv)
 	{
 	    if (TTMaskHasType(&mask, i))
 	    {
-		if (portOnly != TRUE)
-		    CIFCurStyle->cs_labelLayer[i] = CIFCurStyle->cs_nLayers-1;
-		if (noPort != TRUE)
+		if (portOnly == TRUE)
+		{
+		    /* With "port", use layer for port geometry.
+		     * If the port text type has not been set, set it to
+		     * this layer.
+		     */
 		    CIFCurStyle->cs_portLayer[i] = CIFCurStyle->cs_nLayers-1;
+		    if (CIFCurStyle->cs_portText[i] == -1)
+			CIFCurStyle->cs_portText[i] = CIFCurStyle->cs_nLayers-1;
+		}
+		else
+		{
+		    /* For "noport" or no argument, the label text and data
+		     * are set to this layer.  If no argument, then set the
+		     * port text type to this type.  If a later "port" statement
+		     * applies to the same layer, then the data type will be
+		     * separate from the text type.
+		     */ 
+		    CIFCurStyle->cs_labelLayer[i] = CIFCurStyle->cs_nLayers-1;
+		    if (noPort == FALSE)
+			CIFCurStyle->cs_portText[i] = CIFCurStyle->cs_nLayers-1;
+		}
 	    }
 	}
 	cifGotLabels = TRUE;
@@ -992,6 +1018,8 @@ CIFTechLine(sectionName, argc, argv)
 	{
 	    if (strcmp(argv[i], "calma-permissive-labels") == 0)
 		CIFCurStyle->cs_flags |= CWF_PERMISSIVE_LABELS;
+	    else if (strcmp(argv[i], "set-minimum-grid") == 0)
+		CIFCurStyle->cs_flags |= CWF_MINIMUM_GRID;
 	    else if (strcmp(argv[i], "grow-euclidean") == 0)
 		CIFCurStyle->cs_flags |= CWF_GROW_EUCLIDEAN;
 	    else if (strcmp(argv[i], "see-no-vendor") == 0)
@@ -2044,7 +2072,8 @@ CIFTechFinal()
 	for (op = style->cs_layers[i]->cl_ops; (op != NULL) &&
 			(op->co_opcode == CIFOP_OR) &&
 			(TTMaskIsZero(&op->co_cifMask)); op = op->co_next);
-	if (op && (op->co_opcode == CIFOP_SQUARES) && (op->co_next == NULL))
+	if (op && ((op->co_opcode == CIFOP_SQUARES) ||
+		   (op->co_opcode == CIFOP_SQUARES_G)) && (op->co_next == NULL))
 	{
 	    clientdata = op->co_client;
 	    for (op = style->cs_layers[i]->cl_ops; op->co_opcode == CIFOP_OR;
