@@ -4,16 +4,16 @@
  * Procedures to interface the colormap editor with the window package
  * for the purposes of window creation, deletion, and modification.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
@@ -26,9 +26,9 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 #include "utils/magic.h"
 #include "utils/geometry.h"
 #include "windows/windows.h"
+#include "database/database.h"
 #include "tiles/tile.h"
 #include "utils/hash.h"
-#include "database/database.h"
 #include "utils/main.h"
 #include "commands/commands.h"
 #include "cmwind/cmwind.h"
@@ -71,7 +71,7 @@ extern void CMWundoInit();
  * |  | - | |                | | + |        | - | |                | | + |  |
  * |  +---+ +----------------+ +---+        +---+ +----------------+ +---+  |
  * |									    |
- * |               Blue                                 Value  
+ * |               Blue                                 Value
  * |  +---+ +----------------+ +---+        +---+ +----------------+ +---+  |
  * |  | - | |                | | + |        | - | |                | | + |  |
  * |  +---+ +----------------+ +---+        +---+ +----------------+ +---+  |
@@ -91,36 +91,36 @@ extern void CMWundoInit();
 
 ColorBar colorBars[] =
 {
-    "Red",	CB_RED,		STYLE_RED,	{2000,	8000,	10000,	9000},
-						{2000,	9500,	10000,	10500},
-    "Green",	CB_GREEN,	STYLE_GREEN,	{2000,	5000,	10000,	6000},
-						{2000,	6500,	10000,	7500},
-    "Blue",	CB_BLUE,	STYLE_BLUE,	{2000,	2000,	10000,	3000},
-						{2000,	3500,	10000,	4500},
-    "Hue",	CB_HUE,		STYLE_YELLOW,	{14000,	8000,	22000,	9000},
-						{14000,	9500,	22000,	10500},
-    "Saturation",  CB_SAT,	STYLE_GRAY,	{14000,	5000,	22000,	6000},
-						{14000,	6500,	22000,	7500},
-    "Value",	CB_VALUE,	STYLE_BROWN1,	{14000,	2000,	22000,	3000},
-						{14000,	3500,	22000,	4500},
-    0
+    {"Red",	CB_RED,		STYLE_RED,	{{ 2000,	8000},	{10000,	 9000}},
+						{{ 2000,	9500},	{10000,	10500}}},
+    {"Green",	CB_GREEN,	STYLE_GREEN,	{{ 2000,	5000},	{10000,	 6000}},
+						{{ 2000,	6500},	{10000,	 7500}}},
+    {"Blue",	CB_BLUE,	STYLE_BLUE,	{{ 2000,	2000},	{10000,	 3000}},
+						{{ 2000,	3500},	{10000,	 4500}}},
+    {"Hue",	CB_HUE,		STYLE_YELLOW,	{{14000,	8000},	{22000,	 9000}},
+						{{14000,	9500},	{22000,	10500}}},
+    {"Saturation", CB_SAT,	STYLE_GRAY,	{{14000,	5000},	{22000,	 6000}},
+						{{14000,	6500},	{22000,	 7500}}},
+    {"Value",	CB_VALUE,	STYLE_BROWN1,	{{14000,	2000},	{22000,	 3000}},
+						{{14000,	3500},	{22000,	 4500}}},
+    {0}
 };
 
 ColorPump colorPumps[] =
 {
-    CB_RED,	-.0078,	  {500,	8000,	 1500,	9000},
-    CB_RED,	 .0078,	{10500, 8000,	11500,	9000},
-    CB_GREEN,	-.0078,	  {500,	5000,	 1500,	6000},
-    CB_GREEN,	 .0078,	{10500,	5000,	11500,	6000},
-    CB_BLUE,	-.0078,	  {500,	2000,	 1500,	3000},
-    CB_BLUE,	 .0078,	{10500,	2000,	11500,	3000},
-    CB_HUE,	-.01,	{12500,	8000,	13500,	9000},
-    CB_HUE,	 .01,	{22500,	8000,	23500,	9000},
-    CB_SAT,	-.01,	{12500,	5000,	13500,	6000},
-    CB_SAT,	 .01,	{22500,	5000,	23500,	6000},
-    CB_VALUE,	-.01,	{12500,	2000,	13500,	3000},
-    CB_VALUE,	 .01,	{22500,	2000,	23500,	3000},
-    -1
+    {CB_RED,	-.0078,	{{  500, 8000},	{ 1500,	9000}}},
+    {CB_RED,	 .0078,	{{10500, 8000},	{11500,	9000}}},
+    {CB_GREEN,	-.0078,	{{  500, 5000},	{ 1500,	6000}}},
+    {CB_GREEN,	 .0078,	{{10500, 5000},	{11500,	6000}}},
+    {CB_BLUE,	-.0078,	{{  500, 2000},	{ 1500,	3000}}},
+    {CB_BLUE,	 .0078,	{{10500, 2000},	{11500,	3000}}},
+    {CB_HUE,	-.01,	{{12500, 8000},	{13500,	9000}}},
+    {CB_HUE,	 .01,	{{22500, 8000},	{23500,	9000}}},
+    {CB_SAT,	-.01,	{{12500, 5000},	{13500,	6000}}},
+    {CB_SAT,	 .01,	{{22500, 5000},	{23500,	6000}}},
+    {CB_VALUE,	-.01,	{{12500, 2000},	{13500,	3000}}},
+    {CB_VALUE,	 .01,	{{22500, 2000},	{23500,	3000}}},
+    {-1}
 };
 
 Rect cmwCurrentColorArea = {{6000, 12000}, {18000, 15000}};
@@ -130,13 +130,13 @@ char *cmwCurrentColorText = "Color Being Edited";
 /* Bounding rectangle for entire window */
 
 Rect colorWindowRect = {{0, 1500}, {24000, 17000}};
-
+
 /*
  * ----------------------------------------------------------------------------
  *
  * CMWcreate --
  *
- * A new window has been created.  Create and initialize the needed 
+ * A new window has been created.  Create and initialize the needed
  * structures.
  *
  * Results:
@@ -171,7 +171,7 @@ CMWcreate(window, argc, argv)
     CMWloadWindow(window, color);
     return (TRUE);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -200,7 +200,7 @@ CMWdelete(window)
     freeMagic((char *) cr);
     return (TRUE);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -227,7 +227,7 @@ CMWreposition(window, newScreenArea, final)
 	WindMove(window, &colorWindowRect);
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -332,7 +332,7 @@ CMWredisplay(w, rootArea, clipArea)
      * to that color.  Instead, change the color in a particular style
      * reserved for our own use.
      */
-    
+
     if (GEO_TOUCH(&cmwCurrentColorArea, rootArea))
     {
 	GrStyleTable[STYLE_CMEDIT].color = cr->cmw_color;
@@ -353,7 +353,7 @@ CMWredisplay(w, rootArea, clipArea)
 
     GrUnlock(w);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -389,7 +389,7 @@ CMWloadWindow(w, color)
     /* move the contents of the window so the color bars show */
     WindMove(w, &colorWindowRect);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
