@@ -219,7 +219,7 @@ extRelocateSubstrateCoupling(table, subsnode)
     NodeRegion *rbp;
 
     HashStartSearch(&hs);
-    while (he = HashNext(table, &hs))
+    while ((he = HashNext(table, &hs)))
     {
 	cap = extGetCapValue(he);
 	if (cap == 0) continue;
@@ -275,7 +275,7 @@ extOutputCoupling(table, outFile)
     CapValue cap;  /* value of capacitance. */
 
     HashStartSearch(&hs);
-    while (he = HashNext(table, &hs))
+    while ((he = HashNext(table, &hs)))
     {
 	cap = extGetCapValue(he) / ExtCurStyle->exts_capScale;
 	if (cap == 0)
@@ -464,7 +464,7 @@ extAddOverlap(tbelow, ecpls)
      * Deduct the area shielded from the area of the overlap, so we adjust
      * the overlap capacitance correspondingly.
      */
-    if (ov.o_pmask = ExtCurStyle->exts_overlapShieldPlanes[ta][tb])
+    if ((ov.o_pmask = ExtCurStyle->exts_overlapShieldPlanes[ta][tb]))
     {
 	ov.o_tmask = ExtCurStyle->exts_overlapShieldTypes[ta][tb];
 	for (pNum = PL_TECHDEPBASE; pNum < DBNumPlanes; pNum++)
