@@ -213,7 +213,7 @@ ExtTimes(rootUse, f)
      */
     TxPrintf("Computing individual cell statistics:\n"); TxFlush();
     HashStartSearch(&hs);
-    while (he = HashNext(&cellStatsTable, &hs))
+    while ((he = HashNext(&cellStatsTable, &hs)))
 	extTimesCellFunc((struct cellStats *) HashGetValue(he));
 
     /*
@@ -223,7 +223,7 @@ ExtTimes(rootUse, f)
      */
     TxPrintf("Computing hierarchical and incremental statistics:\n"); TxFlush();
     HashStartSearch(&hs);
-    while (he = HashNext(&cellStatsTable, &hs))
+    while ((he = HashNext(&cellStatsTable, &hs)))
 	extTimesIncrFunc((struct cellStats *) HashGetValue(he));
 
     /*
@@ -232,7 +232,7 @@ ExtTimes(rootUse, f)
      */
     TxPrintf("Computing summary statistics:\n"); TxFlush();
     HashStartSearch(&hs);
-    while (he = HashNext(&cellStatsTable, &hs))
+    while ((he = HashNext(&cellStatsTable, &hs)))
     {
 	extTimesSummaryFunc((struct cellStats *) HashGetValue(he), f);
 	freeMagic((char *) HashGetValue(he));
