@@ -1079,7 +1079,7 @@ char *name;
 	static int WindowNumber = 0;
 	HashEntry	*entry;
 	char	*windowplace;
-	char	windowname[10];
+	char	windowname[32];
 	int		x      = w->w_frameArea.r_xbot;
 	int		y      = grTransYs(w->w_frameArea.r_ytop);
 	int		width  = w->w_frameArea.r_xtop - w->w_frameArea.r_xbot;
@@ -1090,7 +1090,7 @@ char *name;
 	WindSeparateRedisplay(w);
 
 	sprintf(windowname, ".magic%d", WindowNumber + 1);
-	if (windowplace = XGetDefault(grXdpy, "magic", windowname))
+	if ((windowplace = XGetDefault(grXdpy, "magic", windowname)))
 	{
 		XParseGeometry(windowplace, &x, &y,
 		               (unsigned int *)&width, (unsigned int *)&height);
@@ -1106,7 +1106,7 @@ char *name;
 	grAttributes.background_pixel = WhitePixel(grXdpy, grXscrn);
 	grAttributes.border_pixel = BlackPixel(grXdpy, grXscrn);
 
-	if (tktop = Tk_MainWindow(magicinterp))
+	if ((tktop = Tk_MainWindow(magicinterp)))
 	{
 		if (!WindowNumber)
 		{
@@ -1490,7 +1490,7 @@ char	*text;
 	XSetClassHint( grXdpy, wind, &class);
 	if (text)
 	{
-		if (brack = strchr(text, '['))
+		if ((brack = strchr(text, '[')))
 		{
 			brack--;
 			*brack = 0;
@@ -1499,7 +1499,7 @@ char	*text;
 			*brack = ' ';
 			return;
 		}
-		if (brack = strrchr(text, ' ')) text = brack + 1;
+		if ((brack = strrchr(text, ' '))) text = brack + 1;
 		XSetIconName(grXdpy, wind, text);
 		XStoreName(grXdpy, wind, text);
 	}
