@@ -2,28 +2,28 @@
  * irCommand.c --
  *
  * Command interface for interactive router.  This file processes command
- * lines beginning with the `iroute' command.  
- * 
- * (The "wizard" command, `*iroute', for testing, debugging, etc., 
+ * lines beginning with the `iroute' command.
+ *
+ * (The "wizard" command, `*iroute', for testing, debugging, etc.,
  *  is processed in irTestCmd.c.)
- * 
- *     ********************************************************************* 
+ *
+ *     *********************************************************************
  *     * Copyright (C) 1987, 1990 Michael H. Arnold, Walter S. Scott, and  *
- *     * the Regents of the University of California.                      * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     * the Regents of the University of California.                      *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  *
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-7.5/irouter/irCommand.c,v 1.7 2006/12/02 00:36:58 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/irouter/irCommand.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -65,9 +65,9 @@ typedef struct
     char 	*sC_usage;		/* command syntax */
 
 } SubCmdTableE;
-extern SubCmdTableE irSubcommands[]; 
+extern SubCmdTableE irSubcommands[];
+
 
-
 /*
  * ----------------------------------------------------------------------------
  *
@@ -91,7 +91,7 @@ extern SubCmdTableE irSubcommands[];
  *      TxPrintf
  *
  *	If file is (FILE *)1, parameter value is returned as a Tcl object
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -110,10 +110,10 @@ irSetNoisyAutoInt(parm, valueS, file)
 	char	*sv_name;	/* name */
 	int	 sv_type;
     } specialValues[] = {
-	"automatic",	V_AUTOMATIC,
-	0
+	{"automatic",	V_AUTOMATIC},
+	{0}
     };
-    
+
     /* If value non-null set parm */
     if(valueS!=NULL)
     {
@@ -122,7 +122,7 @@ irSetNoisyAutoInt(parm, valueS, file)
     	/* check if special value */
 	which = LookupStruct(
 	    valueS,
-	    (char **) specialValues, 
+	    (char **) specialValues,
 	    sizeof specialValues[0]);
 
 	if(which == -1)
@@ -179,13 +179,13 @@ irSetNoisyAutoInt(parm, valueS, file)
 	else
 	{
 	    TxPrintf("%8d ",*parm);
-	}   
+	}
     }
 
     return;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -200,7 +200,7 @@ irSetNoisyAutoInt(parm, valueS, file)
  *	Call low level routine of appropriate type to set/display parameter.
  *	Value of parm can be displayed either in Magic text window (file is
  *      NULL) or to a file.
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -232,6 +232,19 @@ irLSetWidth(rL,s,file)
     return NULL;
 }
 
+/* irLSetLength -- */
+Tcl_Obj *
+irLSetLength(rL,s,file)
+    RouteLayer *rL;
+    char *s;
+    FILE *file;
+{
+    if (file == (FILE *)1)
+	return Tcl_NewIntObj(rL->rl_routeType.rt_length);
+    SetNoisyInt(&(rL->rl_routeType.rt_length),s,file);
+    return NULL;
+}
+
 /* irLSetHCost -- */
 Tcl_Obj *
 irLSetHCost(rL,s,file)
@@ -244,7 +257,7 @@ irLSetHCost(rL,s,file)
     SetNoisyInt(&(rL->rl_hCost),s,file);
     return NULL;
 }
-	
+
 /* irLSetVCost -- */
 Tcl_Obj *
 irLSetVCost(rL,s,file)
@@ -319,6 +332,16 @@ irLSetWidth(rL,s,file)
     SetNoisyInt(&(rL->rl_routeType.rt_width),s,file);
 }
 
+/* irLSetLength -- */
+void
+irLSetLength(rL,s,file)
+    RouteLayer *rL;
+    char *s;
+    FILE *file;
+{
+    SetNoisyInt(&(rL->rl_routeType.rt_length),s,file);
+}
+
 /* irLSetHCost -- */
 void
 irLSetHCost(rL,s,file)
@@ -328,7 +351,7 @@ irLSetHCost(rL,s,file)
 {
     SetNoisyInt(&(rL->rl_hCost),s,file);
 }
-	
+
 /* irLSetVCost -- */
 void
 irLSetVCost(rL,s,file)
@@ -349,7 +372,7 @@ irLSetJogCost(rL,s,file)
     SetNoisyInt(&(rL->rl_jogCost),s,file);
 }
 
- 
+
 /* irLSetHintCost  -- */
 void
 irLSetHintCost(rL,s,file)
@@ -372,7 +395,7 @@ irLSetOverCost(rL,s,file)
 
 #endif
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -387,10 +410,10 @@ irLSetOverCost(rL,s,file)
  *	Call low level routine of appropriate type to set/display parameter.
  *	Value of parm can be displayed either in Magic text window (file is
  *      NULL) or to a file.
- *	
+ *
  * ----------------------------------------------------------------------------
  */
-	
+
 #ifdef MAGIC_WRAPPER
 
 /* irCSetActive -- */
@@ -418,7 +441,20 @@ irCSetWidth(rC,s,file)
     SetNoisyInt(&(rC->rc_routeType.rt_width),s,file);
     return NULL;
 }
-	
+
+/* irCSetLength--  */
+Tcl_Obj *
+irCSetLength(rC,s,file)
+    RouteContact *rC;
+    char *s;
+    FILE *file;
+{
+    if (file == (FILE *)1)
+	return Tcl_NewIntObj(rC->rc_routeType.rt_length);
+    SetNoisyInt(&(rC->rc_routeType.rt_length),s,file);
+    return NULL;
+}
+
 /* irCSetCost -- */
 Tcl_Obj *
 irCSetCost(rC,s,file)
@@ -453,7 +489,17 @@ irCSetWidth(rC,s,file)
 {
     SetNoisyInt(&(rC->rc_routeType.rt_width),s,file);
 }
-	
+
+/* irCSetLength --  */
+void
+irCSetLength(rC,s,file)
+    RouteContact *rC;
+    char *s;
+    FILE *file;
+{
+    SetNoisyInt(&(rC->rc_routeType.rt_length),s,file);
+}
+
 /* irCSetCost -- */
 void
 irCSetCost(rC,s,file)
@@ -467,7 +513,7 @@ irCSetCost(rC,s,file)
 
 #endif
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -482,11 +528,11 @@ irCSetCost(rC,s,file)
  *	Call low level routine of appropriate type to set/display parameter.
  *	Value of parm can be displayed either in Magic text window (file is
  *      NULL) or to a file.
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
-
+
 /* irSrSetRate -- */
 void
 irSrSetRate(s,file)
@@ -505,7 +551,7 @@ irSrSetWidth(s,file)
     SetNoisyDI(&(irMazeParms->mp_wWidth),s,file);
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -520,7 +566,7 @@ irSrSetWidth(s,file)
  *	Call low level routine of appropriate type to set/display parameter.
  *	Value of parm can be displayed either in Magic text window (file is
  *      NULL) or to a file.
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -581,7 +627,7 @@ irWzdSetPenalty(s, file)
 	float value;
 	if(sscanf(s,"%f",&value)==1)
 	{
-	    irMazeParms->mp_penalty.rf_mantissa = 
+	    irMazeParms->mp_penalty.rf_mantissa =
 		    (int) (value * (1<<irMazeParms->mp_penalty.rf_nExponent));
 	}
 	else
@@ -633,9 +679,9 @@ FILE *file;
 	char	*sp_name;	/* name */
 	int	 sp_type;
     } specialArgs[] = {
-	"command",	SP_COMMAND,
-	".",		SP_DOT,
-	0
+	{"command",	SP_COMMAND},
+	{".",		SP_DOT},
+	{0}
     };
 
     if(s!=NULL)
@@ -644,7 +690,7 @@ FILE *file;
 	/* check if special arg */
 	which = LookupStruct(
 	    s,
-	    (char **) specialArgs, 
+	    (char **) specialArgs,
 	    sizeof specialArgs[0]);
 
 	if(which == -1)
@@ -708,11 +754,11 @@ FILE *file;
 	    TxPrintf("%d",irRouteWid);
 	}
     }
-    
+
     return;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -725,7 +771,7 @@ FILE *file;
  *
  * Side effects:
  *	Modify contact parameters and display them.
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -739,10 +785,11 @@ static struct
     void    	(*cP_proc)();	/* Procedure processing this parameter */
 #endif
 } cParms[] = {
-    "active",	irCSetActive,
-    "width",	irCSetWidth,
-    "cost",	irCSetCost,
-    0
+    {"active",	irCSetActive},
+    {"width",	irCSetWidth},
+    {"length",	irCSetLength},
+    {"cost",	irCSetCost},
+    {0}
 };
 
 /* NEXTVALUE - returns pointer to next value arg (string). */
@@ -775,11 +822,11 @@ irContactsCmd(w, cmd)
 #endif
 
     nV_i = argc - 1;
-    
+
     /* Process by case */
     if(argc == 2 ||
 	(argc == 3 && (strcmp(cmd->tx_argv[2],"*")==0)) ||
-	(argc >= 4 && 
+	(argc >= 4 &&
 	    (strcmp(cmd->tx_argv[2],"*")==0) &&
 	    (strcmp(cmd->tx_argv[3],"*")==0)))
     {
@@ -844,14 +891,14 @@ irContactsCmd(w, cmd)
 	/* PROCESS ALL PARMS ASSOCIATED WITH CONTACT */
 	/* convert layer string to tileType */
 	tileType = DBTechNameType(cmd->tx_argv[2]);
-	if(tileType<0) 
+	if(tileType<0)
 	{
-	    TxError("Unrecognized layer (type): \"%.20s\"\n", 
+	    TxError("Unrecognized layer (type): \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
 
-	if(rC=irFindRouteContact(tileType))
+	if((rC=irFindRouteContact(tileType)))
 	{
 	    /* Print Contact Heading */
 	    TxPrintf("%-12.12s ", "contact");
@@ -877,9 +924,9 @@ irContactsCmd(w, cmd)
 	    }
 	    TxPrintf("\n");
 	}
-	else 
+	else
 	{
-	    TxError("Unrecognized route-contact: \"%.20s\"\n", 
+	    TxError("Unrecognized route-contact: \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
@@ -887,18 +934,18 @@ irContactsCmd(w, cmd)
     else if(argc>=4 && strcmp(cmd->tx_argv[2],"*")==0)
     {
 	/* PROCESS A COLUMN (THE VALUES OF A PARAMETER FOR ALL CONTACTS) */
-     
+
 	/* Lookup parameter name in contact parm table */
 	which = LookupStruct(
-	    cmd->tx_argv[3], 
-	    (char **) cParms, 
+	    cmd->tx_argv[3],
+	    (char **) cParms,
 	    sizeof cParms[0]);
 
 	/* Process table lookup */
 	if (which == -1)
 	{
 	    /* AMBIGUOUS PARAMETER */
-	    TxError("Ambiguous parameter: \"%s\"\n", 
+	    TxError("Ambiguous parameter: \"%s\"\n",
 		cmd->tx_argv[3]);
 	    return;
 	}
@@ -913,7 +960,7 @@ irContactsCmd(w, cmd)
 	    return;
 	}
 
-	else 
+	else
 	{
 	    /* CONTACT PARAMETER FOUND */
 
@@ -942,25 +989,25 @@ irContactsCmd(w, cmd)
 	/* PROCESS PARAMETER ASSOCIATED WITH CONTACT */
 	/* convert layer string to tileType */
 	tileType = DBTechNameType(cmd->tx_argv[2]);
-	if(tileType<0) 
+	if(tileType<0)
 	{
-	    TxError("Unrecognized layer (type): \"%.20s\"\n", 
+	    TxError("Unrecognized layer (type): \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
 
-	if(rC=irFindRouteContact(tileType))
+	if((rC=irFindRouteContact(tileType)))
 	{
 	    /* Lookup contact parameter name in table */
 	    which = LookupStruct(
-		cmd->tx_argv[3], 
-		(char **) cParms, 
+		cmd->tx_argv[3],
+		(char **) cParms,
 		sizeof cParms[0]);
 
 	    /* Process result of lookup */
 	    if (which >= 0)
 	    {
-		/* parameter found - call proc that processes it 
+		/* parameter found - call proc that processes it
 		 * NULL second arg means display only
 		 */
 		(*cParms[which].cP_proc)(rC,NEXTVALUE,NULL);
@@ -969,7 +1016,7 @@ irContactsCmd(w, cmd)
 	    else if (which == -1)
 	    {
 		/* ambiguous parameter - complain */
-		TxError("Ambiguous parameter: \"%s\"\n", 
+		TxError("Ambiguous parameter: \"%s\"\n",
 		    cmd->tx_argv[3]);
 		return;
 	    }
@@ -984,9 +1031,9 @@ irContactsCmd(w, cmd)
 		return;
 	    }
 	}
-	else 
+	else
 	{
-	    TxError("Unrecognized route-contact: \"%.20s\"\n", 
+	    TxError("Unrecognized route-contact: \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
@@ -1002,7 +1049,7 @@ irContactsCmd(w, cmd)
     return;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1016,7 +1063,7 @@ irContactsCmd(w, cmd)
  *
  * Side effects:
  *	Display requested help info.
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -1046,8 +1093,8 @@ irHelpCmd(w, cmd)
     {
 	/* Lookup subcommand in table, and printed associated help info */
 	which = LookupStruct(
-	    cmd->tx_argv[2], 
-	    (char **) irSubcommands, 
+	    cmd->tx_argv[2],
+	    (char **) irSubcommands,
 	    sizeof irSubcommands[0]);
 
         /* Process result of lookup */
@@ -1068,7 +1115,7 @@ irHelpCmd(w, cmd)
 	else
 	{
 	    /* unrecognized subcommand - complain */
-	    TxError("Unrecognized iroute subcommand: \"%s\"\n", 
+	    TxError("Unrecognized iroute subcommand: \"%s\"\n",
 		    cmd->tx_argv[2]);
 	    TxError("Valid iroute irSubcommands are:  ");
 	    for (n = 0; irSubcommands[n].sC_name; n++)
@@ -1080,7 +1127,7 @@ irHelpCmd(w, cmd)
     return;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1093,7 +1140,7 @@ irHelpCmd(w, cmd)
  *
  * Side effects:
  *	Modify contact parameters and display them.
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -1107,14 +1154,15 @@ static struct
     void	(*lP_proc)();	/* procedure processing this parameter */
 #endif
 } lParms[] = {
-    "active",	irLSetActive,
-    "width",	irLSetWidth,
-    "hCost",	irLSetHCost,
-    "vCost",	irLSetVCost,
-    "jogCost",	irLSetJogCost,
-    "hintCost", irLSetHintCost,
-    "overCost", irLSetOverCost,
-    0
+    {"active",	irLSetActive},
+    {"width",	irLSetWidth},
+    {"length",	irLSetLength},
+    {"hCost",	irLSetHCost},
+    {"vCost",	irLSetVCost},
+    {"jogCost",	irLSetJogCost},
+    {"hintCost", irLSetHintCost},
+    {"overCost", irLSetOverCost},
+    {0}
 };
 
 /* NEXTVALUE - returns pointer to next value arg (string). */
@@ -1124,7 +1172,7 @@ static struct
     (nV_i >= argc-1) ? cmd->tx_argv[nV_i=4] : cmd->tx_argv[++nV_i] \
 )
 
-    /*ARGSUSED*/	
+    /*ARGSUSED*/
 void
 irLayersCmd(w, cmd)
     MagWindow *w;
@@ -1148,11 +1196,11 @@ irLayersCmd(w, cmd)
 #endif
 
     nV_i = argc - 1;
-    
+
     /* Process by case */
     if(argc == 2 ||
 	(argc == 3 && (strcmp(cmd->tx_argv[2],"*")==0)) ||
-	(argc >= 4 && 
+	(argc >= 4 &&
 	    (strcmp(cmd->tx_argv[2],"*")==0) &&
 	    (strcmp(cmd->tx_argv[3],"*")==0)))
     {
@@ -1201,7 +1249,7 @@ irLayersCmd(w, cmd)
 	    /* Process parms for each route layer */
 	    for (rL=irRouteLayers; rL!= NULL; rL=rL->rl_next)
 	    {
-		TxPrintf("%-12.12s ", 
+		TxPrintf("%-12.12s ",
 			DBTypeLongNameTbl[rL->rl_routeType.rt_tileType]);
 		for(n=0; lParms[n].lP_name; n++)
 		{
@@ -1217,14 +1265,14 @@ irLayersCmd(w, cmd)
 	/* PROCESS ALL PARMS ASSOCIATED WITH ROUTE LAYER */
 	/* convert layer string to tileType */
 	tileType = DBTechNameType(cmd->tx_argv[2]);
-	if(tileType<0) 
+	if(tileType<0)
 	{
-	    TxError("Unrecognized layer (type): \"%.20s\"\n", 
+	    TxError("Unrecognized layer (type): \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
 
-	if (rL=irFindRouteLayer(tileType))
+	if ((rL=irFindRouteLayer(tileType)))
 	{
 	    /* Print Route Layer Heading */
 	    TxPrintf("%-12.12s ", "layer");
@@ -1242,7 +1290,7 @@ irLayersCmd(w, cmd)
 	    TxPrintf("\n");
 
 	    /* Process parms for route layer */
-	    TxPrintf("%-12.12s ", 
+	    TxPrintf("%-12.12s ",
 		DBTypeLongNameTbl[rL->rl_routeType.rt_tileType]);
 	    for(n=0; lParms[n].lP_name; n++)
 	    {
@@ -1250,9 +1298,9 @@ irLayersCmd(w, cmd)
 	    }
 	    TxPrintf("\n");
 	}
-	else 
+	else
 	{
-	    TxError("Unrecognized route layer or contact: \"%.20s\"\n", 
+	    TxError("Unrecognized route layer or contact: \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
@@ -1260,18 +1308,18 @@ irLayersCmd(w, cmd)
     else if(argc>=4 && strcmp(cmd->tx_argv[2],"*")==0)
     {
 	/* PROCESS A COLUMN (THE VALUES OF A PARAMETER FOR ALL LAYERS) */
-     
+
 	/* Lookup parameter name in layer parm table */
 	which = LookupStruct(
-	    cmd->tx_argv[3], 
-	    (char **) lParms, 
+	    cmd->tx_argv[3],
+	    (char **) lParms,
 	    sizeof lParms[0]);
 
 	/* Process table lookup */
 	if (which == -1)
 	{
 	    /* AMBIGUOUS PARAMETER */
-	    TxError("Ambiguous parameter: \"%s\"\n", 
+	    TxError("Ambiguous parameter: \"%s\"\n",
 		cmd->tx_argv[3]);
 	    return;
 	}
@@ -1297,14 +1345,14 @@ irLayersCmd(w, cmd)
 	    TxPrintf("\n");
 
 	    TxPrintf("%-12.12s ", irRepeatChar(strlen("layer"),'-'));
-	    TxPrintf("%8.8s ", 
+	    TxPrintf("%8.8s ",
 		irRepeatChar(strlen(lParms[which].lP_name),'-'));
 	    TxPrintf("\n");
 
 	    /* Process parm for each route layer */
 	    for (rL=irRouteLayers; rL!= NULL; rL=rL->rl_next)
 	    {
-		TxPrintf("%-12.12s ", 
+		TxPrintf("%-12.12s ",
 		    DBTypeLongNameTbl[rL->rl_routeType.rt_tileType]);
 		(*lParms[which].lP_proc)(rL,NEXTVALUE,NULL);
 		TxPrintf("\n");
@@ -1317,25 +1365,25 @@ irLayersCmd(w, cmd)
 	/* PROCESS PARAMETER ASSOCIATED WITH ROUTE LAYER */
 	/* convert layer string to tileType */
 	tileType = DBTechNameType(cmd->tx_argv[2]);
-	if(tileType<0) 
+	if(tileType<0)
 	{
-	    TxError("Unrecognized layer (type): \"%.20s\"\n", 
+	    TxError("Unrecognized layer (type): \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
 
-	if (rL=irFindRouteLayer(tileType))
+	if ((rL=irFindRouteLayer(tileType)))
 	{
 	    /* Lookup route layer parameter name in table */
 	    which = LookupStruct(
-		cmd->tx_argv[3], 
-		(char **) lParms, 
+		cmd->tx_argv[3],
+		(char **) lParms,
 		sizeof lParms[0]);
 
 	    /* Process result of lookup */
 	    if (which >= 0)
 	    {
-		/* parameter found - call proc that processes it 
+		/* parameter found - call proc that processes it
 		 * NULL second arg means display only
 		 */
 		(*lParms[which].lP_proc)(rL,NEXTVALUE,NULL);
@@ -1344,7 +1392,7 @@ irLayersCmd(w, cmd)
 	    else if (which == -1)
 	    {
 		/* ambiguous parameter - complain */
-		TxError("Ambiguous parameter: \"%s\"\n", 
+		TxError("Ambiguous parameter: \"%s\"\n",
 		    cmd->tx_argv[3]);
 		return;
 	    }
@@ -1359,9 +1407,9 @@ irLayersCmd(w, cmd)
 		return;
 	    }
 	}
-	else 
+	else
 	{
-	    TxError("Unrecognized layer: \"%.20s\"\n", 
+	    TxError("Unrecognized layer: \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
@@ -1376,20 +1424,20 @@ irLayersCmd(w, cmd)
     return;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
  * irRouteCmd --
  *
- * Irouter subcommand to actually do a route. 
+ * Irouter subcommand to actually do a route.
  *
  * Results:
  *	None.
  *
  * Side effects:
  *	Compute a route and paint it into edit cell.
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -1444,7 +1492,7 @@ irRouteCmd(w, cmd)
     while(i<argc)
     {
 	int which = Lookup(argv[i],&(rOptions[0]));
-	switch (which) 
+	switch (which)
 	{
 	    case -2:
 		/* not found */
@@ -1542,7 +1590,7 @@ irRouteCmd(w, cmd)
 		destRect.r_ytop = cmdParseCoord(w, argv[i], FALSE, FALSE);
 
 		destRectArg = &destRect;
-		break;	    
+		break;
 	    case 4:
 		/* dSelection */
 		destType = DT_SELECTION;
@@ -1676,7 +1724,7 @@ leaveClean:
     return;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1689,7 +1737,7 @@ leaveClean:
  *
  * Side effects:
  *	Modify search parameters and display them.
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -1699,9 +1747,9 @@ static struct
     char	*srP_name;	/* name of parameter */
     void	(*srP_proc)();	/* Procedure processing this parameter */
 } srParms[] = {
-    "rate",		irSrSetRate,
-    "width",		irSrSetWidth,
-    0
+    {"rate",		irSrSetRate},
+    {"width",		irSrSetWidth},
+    {0}
 };
 
 void
@@ -1709,7 +1757,7 @@ irSearchCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    
+
     /* Process by case */
     if(cmd->tx_argc == 2)
     /* print values of all parms */
@@ -1718,7 +1766,7 @@ irSearchCmd(w, cmd)
 
 	for(n=0; srParms[n].srP_name; n++)
 	{
-	    TxPrintf("  %s=", srParms[n].srP_name); 
+	    TxPrintf("  %s=", srParms[n].srP_name);
 	    (*srParms[n].srP_proc)(NULL,NULL);
 	}
 	TxPrintf("\n");
@@ -1730,15 +1778,15 @@ irSearchCmd(w, cmd)
 
 	/* Lookup parameter name in contact parm table */
 	which = LookupStruct(
-	    cmd->tx_argv[2], 
-	    (char **) srParms, 
+	    cmd->tx_argv[2],
+	    (char **) srParms,
 	    sizeof srParms[0]);
 
 	/* Process table lookup */
 	if (which == -1)
 	/* parameter ambiguous */
 	{
-	    TxError("Ambiguous parameter: \"%s\"\n", 
+	    TxError("Ambiguous parameter: \"%s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
@@ -1754,7 +1802,7 @@ irSearchCmd(w, cmd)
 	    TxError("\n");
 	    return;
 	}
-	else 
+	else
 	/* parameter found - process it */
 	{
 	    char *arg;
@@ -1770,7 +1818,7 @@ irSearchCmd(w, cmd)
 		arg = cmd->tx_argv[3];
 	    }
 
-	    TxPrintf("  %s=", srParms[which].srP_name); 
+	    TxPrintf("  %s=", srParms[which].srP_name);
 	    (*srParms[which].srP_proc)(arg,NULL);
 	    TxPrintf("\n");
 	}
@@ -1785,22 +1833,22 @@ irSearchCmd(w, cmd)
     return;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
  * irSpacingsCmd --
  *
- * Irouter subcommand to set and display minimum spacings between 
- * routetypes. 
- * 
+ * Irouter subcommand to set and display minimum spacings between
+ * routetypes.
+ *
  *
  * Results:
  *	None.
  *
  * Side effects:
- *	Modify and display spacing parameters. 
- *	
+ *	Modify and display spacing parameters.
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -1820,11 +1868,11 @@ irSpacingsCmd(w, cmd)
 	char	*sV_name;	/* name of value */
 	int     sV_value;	/* corresponding interger value */
     } sValue[] = {
-	"n",		-1,
-	"nil",		-1,
-	"none",		-1,
-	"null",		-1,
-	0
+	{"n",		-1},
+	{"nil",		-1},
+	{"none",	-1},
+	{"null",	-1},
+	{0}
     };
 
     /* Subcell Table */
@@ -1833,8 +1881,8 @@ irSpacingsCmd(w, cmd)
 	char	*sT_name;	/* name of value */
 	int     sT_value;	/* corresponding interger value */
     } subcellTable[] = {
-	"subcell",		TT_SUBCELL,
-	0
+	{"subcell",		TT_SUBCELL},
+	{0}
     };
 
     /* Process by case */
@@ -1845,7 +1893,7 @@ irSpacingsCmd(w, cmd)
 	/* Print spacings for each route type */
 	for (rT=irRouteTypes; rT!= NULL; rT=rT->rt_next)
 	{
-	    TxPrintf("%s:  ", 
+	    TxPrintf("%s:  ",
 	        DBTypeLongNameTbl[rT->rt_tileType]);
 	    for (i=0;i<TT_MAXTYPES;i++)
 		if(rT->rt_spacing[i]>=0)
@@ -1873,17 +1921,17 @@ irSpacingsCmd(w, cmd)
 
 	    /* convert layer string to tileType */
 	    tileType = DBTechNameType(cmd->tx_argv[2]);
-	    if(tileType<0) 
+	    if(tileType<0)
 	    {
-		TxError("Unrecognized layer (type): \"%.20s\"\n", 
+		TxError("Unrecognized layer (type): \"%.20s\"\n",
 		    cmd->tx_argv[2]);
 		return;
 	    }
 
-	    if (rT=irFindRouteType(tileType))
+	    if ((rT=irFindRouteType(tileType)))
 	    {
 
-		TxPrintf("%s:  ", 
+		TxPrintf("%s:  ",
 		    DBTypeLongNameTbl[rT->rt_tileType]);
 		for (i=0;i<TT_MAXTYPES;i++)
 		    if(rT->rt_spacing[i]>=0)
@@ -1893,9 +1941,9 @@ irSpacingsCmd(w, cmd)
 		    TxPrintf("%s=%d ","SUBCELL",rT->rt_spacing[TT_SUBCELL]);
 		TxPrintf("\n\n");
 	    }
-	    else 
+	    else
 	    {
-		TxError("Unrecognized route layer or contact: \"%.20s\"\n", 
+		TxError("Unrecognized route layer or contact: \"%.20s\"\n",
 		    cmd->tx_argv[2]);
 		return;
 	    }
@@ -1904,26 +1952,26 @@ irSpacingsCmd(w, cmd)
     else if(cmd->tx_argc==4)
     {
 	/* PRINT VALUE OF GIVEN SPACING */
-     
+
 	/* convert layer string to tileType */
 	tileType = DBTechNameType(cmd->tx_argv[2]);
-	if(tileType<0) 
+	if(tileType<0)
 	{
-	    TxError("Unrecognized layer (type): \"%.20s\"\n", 
+	    TxError("Unrecognized layer (type): \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
 
 	if ((rT=irFindRouteType(tileType))==NULL)
 	{
-	    TxError("Unrecognized route layer or contact: \"%.20s\"\n", 
+	    TxError("Unrecognized route layer or contact: \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
 
 	/* convert type-string spacing is "to" to tiletype */
 	tileType = DBTechNameType(cmd->tx_argv[3]);
-	if(tileType<0) 
+	if(tileType<0)
 	{
 	    /* if not a real type, check to see if "SUBCELL" */
 	    which = LookupStruct(
@@ -1933,9 +1981,9 @@ irSpacingsCmd(w, cmd)
 	    if ( which>= 0)
 	        tileType = TT_SUBCELL;
 	}
-	if(tileType<0) 
+	if(tileType<0)
 	{
-	    TxError("Unrecognized layer (type): \"%.20s\"\n", 
+	    TxError("Unrecognized layer (type): \"%.20s\"\n",
 		cmd->tx_argv[3]);
 	    return;
 	}
@@ -1955,19 +2003,19 @@ irSpacingsCmd(w, cmd)
     else
     {
 	/* SET SPACINGS */
-     
+
 	/* convert layer string to tileType */
 	tileType = DBTechNameType(cmd->tx_argv[2]);
-	if(tileType<0) 
+	if(tileType<0)
 	{
-	    TxError("Unrecognized layer (type): \"%.20s\"\n", 
+	    TxError("Unrecognized layer (type): \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
 
 	if ((rT=irFindRouteType(tileType))==NULL)
 	{
-	    TxError("Unrecognized route layer or contact: \"%.20s\"\n", 
+	    TxError("Unrecognized route layer or contact: \"%.20s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
@@ -1980,7 +2028,7 @@ irSpacingsCmd(w, cmd)
 	{
 	    /* convert type-string spacing is "to" to tiletype */
 	    tileType = DBTechNameType(cmd->tx_argv[argI]);
-	    if(tileType<0) 
+	    if(tileType<0)
 	    {
 		/* if not a real type, check to see if "SUBCELL" */
 		which = LookupStruct(
@@ -1990,9 +2038,9 @@ irSpacingsCmd(w, cmd)
 		if ( which>= 0)
 	        tileType = TT_SUBCELL;
 	    }
-	    if(tileType<0) 
+	    if(tileType<0)
 	    {
-		TxError("\nUnrecognized layer (type): \"%.20s\"\n", 
+		TxError("\nUnrecognized layer (type): \"%.20s\"\n",
 		    cmd->tx_argv[argI]);
 		continue;
 	    }
@@ -2017,8 +2065,8 @@ irSpacingsCmd(w, cmd)
 	    {
 		/* Lookup in special value table */
 		which = LookupStruct(
-		    s, 
-		    (char **) sValue, 
+		    s,
+		    (char **) sValue,
 		    sizeof sValue[0]);
 
 		/* Process result of lookup */
@@ -2052,12 +2100,12 @@ irSpacingsCmd(w, cmd)
 	    /* Print new value */
 	    if(rT->rt_spacing[tileType] != -1)
 		TxPrintf(" %s=%d",
-		    (tileType == TT_SUBCELL ? 
+		    (tileType == TT_SUBCELL ?
 			"SUBCELL" : DBTypeLongNameTbl[tileType]),
 			rT->rt_spacing[tileType]);
 	    else
 		TxPrintf(" %s=NIL",
-		    (tileType==TT_SUBCELL ? 
+		    (tileType==TT_SUBCELL ?
 			"SUBCELL" : DBTypeLongNameTbl[tileType]));
 	}
 	TxPrintf("\n");
@@ -2066,7 +2114,7 @@ irSpacingsCmd(w, cmd)
     return;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -2079,7 +2127,7 @@ irSpacingsCmd(w, cmd)
  *
  * Side effects:
  *	Sets verbosity parameter
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -2093,7 +2141,7 @@ irVerbosityCmd(w, cmd)
 	TxError("'iroute verbosity' only takes one arg!\n");
 	return;
     }
-    
+
     if(cmd->tx_argc == 3)
     {
 	int i;
@@ -2117,21 +2165,21 @@ irVerbosityCmd(w, cmd)
 	case 0:
 	/* shhhhh! we're in silent mode */
 	break;
-	    
+
 	case 1:
 	TxPrintf("\t1 (Brief messages)\n");
 	break;
-	    
+
 	default:
 	ASSERT(irMazeParms->mp_verbosity>=2,"irVerbosityCmd");
 	TxPrintf("\t%d (Lots of statistics)\n",
 		 irMazeParms->mp_verbosity);
     }
-    
+
     return;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -2144,7 +2192,7 @@ irVerbosityCmd(w, cmd)
  *
  * Side effects:
  *	Displays version string.
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -2167,7 +2215,7 @@ irVersionCmd(w, cmd)
     return;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -2180,7 +2228,7 @@ irVersionCmd(w, cmd)
  *
  * Side effects:
  *	See above.
- *	
+ *
  * ----------------------------------------------------------------------------
  */
 
@@ -2190,15 +2238,15 @@ static struct
     char	*wzdP_name;	/* name of parameter */
     void	(*wzdP_proc)();	/* Procedure processing this parameter */
 } wzdParms[] = {
-    "bloom",		irWzdSetBloomCost,
-    "bloomLimit",	irWzdSetBloomLimit,
-    "boundsIncrement",	irWzdSetBoundsIncrement,
-    "estimate",		irWzdSetEstimate,
-    "expandEndpoints",	irWzdSetExpandEndpoints,
-    "penalty",		irWzdSetPenalty,
-    "penetration",	irWzdSetPenetration,
-    "window",		irWzdSetWindow,
-    0
+    {"bloom",		irWzdSetBloomCost},
+    {"bloomLimit",	irWzdSetBloomLimit},
+    {"boundsIncrement",	irWzdSetBoundsIncrement},
+    {"estimate",	irWzdSetEstimate},
+    {"expandEndpoints",	irWzdSetExpandEndpoints},
+    {"penalty",		irWzdSetPenalty},
+    {"penetration",	irWzdSetPenetration},
+    {"window",		irWzdSetWindow},
+    {0}
 };
 
 void
@@ -2206,7 +2254,7 @@ irWizardCmd(w, cmd)
     MagWindow *w;
     TxCommand *cmd;
 {
-    
+
     /* Process by case */
     if(cmd->tx_argc == 2)
     /* print values of all parms */
@@ -2215,7 +2263,7 @@ irWizardCmd(w, cmd)
 
 	for(n=0; wzdParms[n].wzdP_name; n++)
 	{
-	    TxPrintf("  %s=", wzdParms[n].wzdP_name); 
+	    TxPrintf("  %s=", wzdParms[n].wzdP_name);
 	    (*wzdParms[n].wzdP_proc)(NULL,NULL);
 	    TxPrintf("\n");
 	}
@@ -2227,15 +2275,15 @@ irWizardCmd(w, cmd)
 
 	/* Lookup parameter name in contact parm table */
 	which = LookupStruct(
-	    cmd->tx_argv[2], 
-	    (char **) wzdParms, 
+	    cmd->tx_argv[2],
+	    (char **) wzdParms,
 	    sizeof wzdParms[0]);
 
 	/* Process table lookup */
 	if (which == -1)
 	/* parameter ambiguous */
 	{
-	    TxError("Ambiguous parameter: \"%s\"\n", 
+	    TxError("Ambiguous parameter: \"%s\"\n",
 		cmd->tx_argv[2]);
 	    return;
 	}
@@ -2251,7 +2299,7 @@ irWizardCmd(w, cmd)
 	    TxError("\n");
 	    return;
 	}
-	else 
+	else
 	/* parameter found - process it */
 	{
 	    char *arg;
@@ -2267,7 +2315,7 @@ irWizardCmd(w, cmd)
 		arg = cmd->tx_argv[3];
 	    }
 
-	    TxPrintf("  %s=", wzdParms[which].wzdP_name); 
+	    TxPrintf("  %s=", wzdParms[which].wzdP_name);
 	    (*wzdParms[which].wzdP_proc)(arg,NULL);
 	    TxPrintf("\n");
 	}
@@ -2296,10 +2344,10 @@ irWizardCmd(w, cmd)
  *
  * Side effects:
  *	Write file of Magic commands to set parms. to current values.
- *	
+ *
  * NOTE:
- *      Note defined after all other commands, so it can make use of 
- *      datastructures defined just in front of other commands, 
+ *      Note defined after all other commands, so it can make use of
+ *      datastructures defined just in front of other commands,
  *      such as the search parameter table.
  * ----------------------------------------------------------------------------
  */
@@ -2325,7 +2373,7 @@ irSaveParametersCmd(w, cmd)
 
     /* open save file */
     saveFile = fopen(cmd->tx_argv[2], "w");
-    if (saveFile == NULL) 
+    if (saveFile == NULL)
     {
 	TxError("Could not open file '%s' for writing.\n", cmd->tx_argv[2]);
 	return;
@@ -2344,7 +2392,7 @@ irSaveParametersCmd(w, cmd)
      * gibberish when the file is sourced.
      */
     fprintf(saveFile,":iroute verbosity 0\n");
-	    
+
     /* save CONTACT parameters */
     for (rC=irRouteContacts; rC!= NULL; rC=rC->rc_next)
     {
@@ -2359,12 +2407,12 @@ irSaveParametersCmd(w, cmd)
 	fprintf(saveFile,"\n");
     }
 
-    /* save LAYER paramters */
+    /* save LAYER parameters */
     for (rL=irRouteLayers; rL!= NULL; rL=rL->rl_next)
     {
 	int n;
 
-	fprintf(saveFile,":iroute layer %s * ", 
+	fprintf(saveFile,":iroute layer %s * ",
 	    DBTypeLongNameTbl[rL->rl_routeType.rt_tileType]);
 	for(n=0; lParms[n].lP_name; n++)
 	{
@@ -2379,8 +2427,8 @@ irSaveParametersCmd(w, cmd)
 
 	for(n=0; srParms[n].srP_name; n++)
 	{
-	    fprintf(saveFile,":iroute search %s ", 
-			   srParms[n].srP_name); 
+	    fprintf(saveFile,":iroute search %s ",
+			   srParms[n].srP_name);
 	    (*srParms[n].srP_proc)(NULL,saveFile);
 	    fprintf(saveFile,"\n");
 	}
@@ -2396,12 +2444,12 @@ irSaveParametersCmd(w, cmd)
 	{
 	    for (i=0;i<TT_MAXTYPES;i++)
 		if(rT->rt_spacing[i]>=0)
-		    fprintf(saveFile,":iroute spacings %s %s %d\n", 
+		    fprintf(saveFile,":iroute spacings %s %s %d\n",
 				   DBTypeLongNameTbl[rT->rt_tileType],
 				   DBTypeLongNameTbl[i],
 				   rT->rt_spacing[i]);
 	    if(rT->rt_spacing[TT_SUBCELL]>=0)
-		fprintf(saveFile,":iroute spacings %s %s %d\n", 
+		fprintf(saveFile,":iroute spacings %s %s %d\n",
 			       DBTypeLongNameTbl[rT->rt_tileType],
 			       "SUBCELL",
 			       rT->rt_spacing[TT_SUBCELL]);
@@ -2414,8 +2462,8 @@ irSaveParametersCmd(w, cmd)
 
 	for(n=0; wzdParms[n].wzdP_name; n++)
 	{
-	    fprintf(saveFile,":iroute wizard %s ", 
-			   wzdParms[n].wzdP_name); 
+	    fprintf(saveFile,":iroute wizard %s ",
+			   wzdParms[n].wzdP_name);
 	    (*wzdParms[n].wzdP_proc)(NULL,saveFile);
 	    fprintf(saveFile,"\n");
 	}
@@ -2424,12 +2472,12 @@ irSaveParametersCmd(w, cmd)
     /* save VERBOSITY parameter (done last so :source is silent) */
     fprintf(saveFile,":iroute verbosity %d\n",
 	    irMazeParms->mp_verbosity);
-    
+
     (void) fclose(saveFile);
     return;
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -2449,7 +2497,7 @@ irSaveParametersCmd(w, cmd)
  *	and call it to do the work of implementing the subcommand.  Each
  *	such procedure is of the following form:
  *
- *	int	
+ *	int
  *	proc(argc, argv)
  *	    int argc;
  *	    char *argv[];
@@ -2462,21 +2510,21 @@ irSaveParametersCmd(w, cmd)
 /*--- Subcommand Table ---*/
 
 SubCmdTableE irSubcommands[] = {
-    "contacts",	irContactsCmd,
+    {"contacts",	irContactsCmd,
     "set route-contact parameters",
     "contacts [type] [parameter] [value1] ... [valuen]\n\
-\t(can use '*' for type or parameter)",
+\t(can use '*' for type or parameter)"},
 
-    "help",		irHelpCmd,
+    {"help",		irHelpCmd,
     "summarize iroute subcommands",
-    "help [subcommand]",
+    "help [subcommand]"},
 
-    "layers",	irLayersCmd,
+    {"layers",	irLayersCmd,
     "set route-layer parameters",
     "layers [type] [parameter] [value1] ... [valuen]\n\
-\t(can use '*' for type or parameter)",
+\t(can use '*' for type or parameter)"},
 
-    "route",	irRouteCmd,
+    {"route",	irRouteCmd,
     "connect point to node(s)",
     "route [options]\n\
 \t-sLayers layers = layers route may start on.\n\
@@ -2487,38 +2535,38 @@ SubCmdTableE irSubcommands[] = {
 \t-dBox = route to box (DEFAULT)\n\
 \t-dLabel name = route to label of given name\n\
 \t-dRect xbot ybot xtop ytop =  route to rectangle of given coordinates\n\
-\t-dSelection = route to selection",
+\t-dSelection = route to selection"},
 
-    "saveParameters",	irSaveParametersCmd,
+    {"saveParameters",	irSaveParametersCmd,
     "write out all irouter parameters\n\
 \t(can be read back with :source)",
-    "saveParameters <filename>",
+    "saveParameters <filename>"},
 
-    "search", irSearchCmd,
+    {"search", irSearchCmd,
     "set parameters controlling the internal search for routes",
-    "search [searchParameter] [value]",
+    "search [searchParameter] [value]"},
 
-    "spacings",	irSpacingsCmd,
+    {"spacings",	irSpacingsCmd,
     "set minimum spacing between route-type and arbitrary type",
     "spacings [route-type] [type] [spacing] ... [typen spacingn]\n\
 \t(types can be 'SUBCELL', spacing can be 'nil')\n\
 iroute spacings CLEAR\n\
-\t(sets all spacings to nil)",
+\t(sets all spacings to nil)"},
 
-    "verbosity", irVerbosityCmd,
+    {"verbosity", irVerbosityCmd,
     "control the amount of messages printed",
     "verbosity [level]\n\
-\t(0 = errors and warnings only, 1 = brief, 2 = lots of statistics)",
+\t(0 = errors and warnings only, 1 = brief, 2 = lots of statistics)"},
 
-    "version",	irVersionCmd,
+    {"version",	irVersionCmd,
     "identify irouter version",
-    "version",
+    "version"},
 
-    "wizard", irWizardCmd,
+    {"wizard", irWizardCmd,
     "set miscellaneous parameters",
-    "wizard [wizardParameter] [value]",
+    "wizard [wizardParameter] [value]"},
 
-    0
+    {0}
 }, *subCmdP;
 
 void
@@ -2555,7 +2603,7 @@ IRCommand(w, cmd)
 	 * NULL below.
 	 */
 	irResult = irRoute(w, ST_CURSOR,
-		(Point*)NULL, (char*)NULL, (List*)NULL,     
+		(Point*)NULL, (char*)NULL, (List*)NULL,
 		DT_BOX, (Point*)NULL, (char*)NULL, (List*)NULL);
 
 #ifdef MAGIC_WRAPPER
@@ -2588,8 +2636,8 @@ IRCommand(w, cmd)
     {
 	/* Lookup subcommand in table */
 	which = LookupStruct(
-	    cmd->tx_argv[1], 
-	    (char **) irSubcommands, 
+	    cmd->tx_argv[1],
+	    (char **) irSubcommands,
 	    sizeof irSubcommands[0]);
 
         /* Process result of lookup */
@@ -2607,7 +2655,7 @@ IRCommand(w, cmd)
 	else
 	{
 	    /* unrecognized subcommand - complain */
-	    TxError("Unrecognized iroute subcommand: \"%s\"\n", 
+	    TxError("Unrecognized iroute subcommand: \"%s\"\n",
 		    cmd->tx_argv[1]);
 	    TxError("Valid iroute irSubcommands are:  ");
 	    for (n = 0; irSubcommands[n].sC_name; n++)
