@@ -4,16 +4,16 @@
  * Plowing rules.
  * These are applied by plowProcessEdge() for each edge that is to be moved.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
@@ -41,7 +41,7 @@ int plowSliverBotExtent(), plowSliverBotMove();
 int plowApplyRule();
 int plowPenumbraRule();
 bool plowSliverApplyRules();
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -89,7 +89,7 @@ prClearUmbra(edge)
     (void) plowSrShadow(edge->e_pNum, &edge->e_rect,
 		rhsTypes, plowApplyRule, (ClientData) &ar);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -141,7 +141,7 @@ prUmbra(edge, rules)
 			pr->pr_oktypes, plowApplyRule, (ClientData) &ar);
     }
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -260,8 +260,9 @@ prPenumbraBot(edge, rules)
 		GMASK_WEST|GMASK_NORTH|GMASK_SOUTH,
 		plowPenumbraBotProc, (ClientData) &ar);
     }
+    return 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -435,7 +436,7 @@ plowPenumbraRule(impactedEdge, ar)
     int newsep, oldsep, newx;
 
     oldsep = impactedEdge->e_x - movingEdge->e_x;
-    if (pr = ar->ar_rule)
+    if ((pr = ar->ar_rule))
     {
 	if (!TTMaskHasType(&pr->pr_oktypes, impactedEdge->e_ltype))
 	    return (0);
@@ -455,7 +456,7 @@ plowPenumbraRule(impactedEdge, ar)
 
     return (0);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -468,7 +469,7 @@ plowPenumbraRule(impactedEdge, ar)
  * The second pass actually queues the edges to be moved.
  *
  * Results:
- *	None.
+ *	Return 0 always
  *
  * Side effects:
  *	May add an edge to the queue of edges to be processed.
@@ -476,7 +477,7 @@ plowPenumbraRule(impactedEdge, ar)
  * ----------------------------------------------------------------------------
  */
 
-void
+int
 prSliverTop(edge, rules)
     Edge *edge;
     PlowRule *rules;
@@ -493,7 +494,7 @@ prSliverTop(edge, rules)
      * we play conservative and just use the maximum halo size.
      */
     if (plowMaxDist[edge->e_ltype] == 0)
-	return;
+	return 0;
     ar.ar_clip.p_x = edge->e_newx;
     ar.ar_clip.p_y = edge->e_ytop + plowMaxDist[edge->e_ltype];
     startPoint.p_x = edge->e_x;
@@ -527,6 +528,7 @@ prSliverTop(edge, rules)
 		    GMASK_SOUTH|GMASK_NORTH,
 		    plowSliverTopMove, (ClientData) &ar);
     }
+    return 0;
 }
 
 int
@@ -547,7 +549,7 @@ prSliverBot(edge, rules)
      * we play conservative and just use the maximum halo size.
      */
     if (plowMaxDist[edge->e_ltype] == 0)
-	return;
+	return 0;
     ar.ar_clip.p_x = edge->e_newx;
     ar.ar_clip.p_y = edge->e_ybot - plowMaxDist[edge->e_ltype];
     startPoint.p_x = edge->e_x;
@@ -582,8 +584,9 @@ prSliverBot(edge, rules)
 		    GMASK_SOUTH|GMASK_NORTH,
 		    plowSliverBotMove, (ClientData) &ar);
     }
+    return 0;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -678,7 +681,7 @@ plowSliverBotMove(outline, ar)
     /* Keep going */
     return (0);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -919,7 +922,7 @@ plowSliverBotExtent(outline, ar)
 	ar->ar_mustmove = xmove;
     return (ret);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -970,7 +973,7 @@ plowSliverApplyRules(ar, far, farDist)
 	    return (TRUE);
     return (FALSE);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
