@@ -178,9 +178,11 @@ ResReadSim(simfile, fetproc, capproc, resproc, attrproc, mergeproc, subproc)
 		break;
 	    case 'A':
 		if (attrproc)
+		{
 		    result = (*attrproc)(line[ATTRIBUTENODENAME],
 			    line[ATTRIBUTEVALUE], simfile, &extfile);
-		    break;
+		}
+		break;
 	    case 'x':
 		fettype = DBNumTypes;
 		break;
@@ -265,7 +267,7 @@ ResReadNode(nodefile)
 	node->rs_bbox.r_xtop = atoi(line[NODE_BBOX_UR_X]);
 	node->rs_bbox.r_ytop = atoi(line[NODE_BBOX_UR_Y]);
 #endif
-	if (cp = strchr(line[NODES_NODETYPE], ';')) *cp = '\0';
+	if ((cp = strchr(line[NODES_NODETYPE], ';'))) *cp = '\0';
 	node->type = DBTechNameType(line[NODES_NODETYPE]);
 
 	if (node->type == -1)
@@ -866,7 +868,7 @@ ResSimAttribute(aname, avalue, rootname, readextfile)
 	}
     }
 #endif
-    if (avalue = strchr(avalue, ','))
+    if ((avalue = strchr(avalue, ',')))
     {
         ResSimAttribute(aname, avalue + 1, rootname, readextfile);
     }
